@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,12 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.appengine_logging import gapic_version as package_version
+
+__version__ = package_version.__version__
 
 
-from google.cloud.appengine_logging_v1.types.request_log import LogLine
-from google.cloud.appengine_logging_v1.types.request_log import RequestLog
-from google.cloud.appengine_logging_v1.types.request_log import SourceLocation
-from google.cloud.appengine_logging_v1.types.request_log import SourceReference
+from google.cloud.appengine_logging_v1.types.request_log import (
+    LogLine,
+    RequestLog,
+    SourceLocation,
+    SourceReference,
+)
 
 __all__ = (
     "LogLine",
