@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,12 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .request_log import (
-    LogLine,
-    RequestLog,
-    SourceLocation,
-    SourceReference,
-)
+from .request_log import LogLine, RequestLog, SourceLocation, SourceReference
 
 __all__ = (
     "LogLine",
